@@ -37,3 +37,9 @@ describe "puppetserver ca directory looks correct" do
     its(:content) { should contain '-----BEGIN CERTIFICATE-----' }
   end
 end
+
+describe "puppetserver agent certificate has the expected subject" do
+  describe command("openssl x509 -noout -subject -in /etc/puppet/puppetserver/ca/ca_crt.pem | grep -Po '[^ ]+$' | tr -d '\\n'") do
+    its(:stdout) { should eq 'puppet' }
+  end
+end
